#from distutils.core import setup
#setup(name="ljb",version="1.0",description="this is firt backpage",author="ljb",py_modules=["Test.sendmsg","Test.recvmsg"])


from distutils.core import setup

setup(name="dongGe",author_email="848017622@qq.com", version="1.0", description="dongGe's module", author="dongGe", py_modules=['Test.sendmsg', 'Test.recvmsg'])
